@@ -535,20 +535,31 @@ class RaceEntry(models.Model):
 
 class TestSimpleModel(TestCase):
     def setUp(self):
-        self.serializer = DumpDataSerializer()
+        self.dumpdata = DumpDataSerializer()
+        self.serializer = Serializer(depth=0)
         RaceEntry.objects.create(
             name='John doe',
             runner_number=6014,
-            start_time=datetime.datetime.now(),
-            finish_time=datetime.datetime.now()
+            start_time=datetime.datetime(year=2012, month=4, day=30, hour=9),
+            finish_time=datetime.datetime(year=2012, month=4, day=30, hour=12, minute=25)
         )
 
     def test_simple_model(self):
         self.assertEquals(
-            self.serializer.encode(RaceEntry.objects.all(), 'json'),
+            self.dumpdata.encode(RaceEntry.objects.all(), 'json'),
             serializers.serialize('json', RaceEntry.objects.all())
         )
 
+    def test_csv(self):
+        expected = (
+            "finish_time,start_time,id,name,runner_number\r\n"
+            "2012-04-30 12:25:00,2012-04-30 09:00:00,1,John doe,6014\r\n"
+        )
+        self.assertEquals(
+            self.serializer.encode(RaceEntry.objects.all(), 'csv'),
+            expected
+        )
+
 
 ##### One to one relationships #####
 
@@ -577,12 +588,18 @@ class TestOneToOneModel(TestCase):
             date_of_birth=datetime.datetime(day=5, month=4, year=1979)
         )
 
-    def test_onetoone_dumpdata(self):
+    def test_onetoone_dumpdata_json(self):
         self.assertEquals(
             self.dumpdata.encode(Profile.objects.all(), 'json'),
             serializers.serialize('json', Profile.objects.all())
         )
 
+    def test_onetoone_dumpdata_yaml(self):
+        self.assertEquals(
+            self.dumpdata.encode(Profile.objects.all(), 'yaml'),
+            serializers.serialize('yaml', Profile.objects.all())
+        )
+
     def test_onetoone_nested(self):
         expected = {
             'id': 1,
@@ -690,12 +707,18 @@ class TestFKModel(TestCase):
             date_of_manufacture=datetime.date(day=8, month=8, year=1990)
         )
 
-    def test_fk_dumpdata(self):
+    def test_fk_dumpdata_json(self):
         self.assertEquals(
             self.dumpdata.encode(Vehicle.objects.all(), 'json'),
             serializers.serialize('json', Vehicle.objects.all())
         )
 
+    def test_fk_dumpdata_yaml(self):
+        self.assertEquals(
+            self.dumpdata.encode(Vehicle.objects.all(), 'yaml'),
+            serializers.serialize('yaml', Vehicle.objects.all())
+        )
+
     def test_fk_nested(self):
         expected = {
             'id': 1,
@@ -798,7 +821,7 @@ class TestManyToManyModel(TestCase):
         self.otherbook.authors = [self.mark]
         self.otherbook.save()
 
-    def test_m2m_dumpdata(self):
+    def test_m2m_dumpdata_json(self):
         self.assertEquals(
             self.dumpdata.encode(Book.objects.all(), 'json'),
             serializers.serialize('json', Book.objects.all())
@@ -808,6 +831,16 @@ class TestManyToManyModel(TestCase):
             serializers.serialize('json', Author.objects.all())
         )
 
+    def test_m2m_dumpdata_yaml(self):
+        self.assertEquals(
+            self.dumpdata.encode(Book.objects.all(), 'yaml'),
+            serializers.serialize('yaml', Book.objects.all())
+        )
+        self.assertEquals(
+            self.dumpdata.encode(Author.objects.all(), 'yaml'),
+            serializers.serialize('yaml', Author.objects.all())
+        )
+
     def test_m2m_nested(self):
         expected = {
             'id': 1,
